Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(873)

Unified Diff: tests/version_tests/version_tests.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/unsorted/unsorted.status ('k') | third_party/bin/README.md » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/version_tests/version_tests.dart
diff --git a/tests/version_tests/version_tests.dart b/tests/version_tests/version_tests.dart
index fb76898ca979d521ea97653741247462312e4ae3..ce27b417f7195d079072f5799dca5a03f574de63 100644
--- a/tests/version_tests/version_tests.dart
+++ b/tests/version_tests/version_tests.dart
@@ -19,13 +19,13 @@ Future<Null> main() async {
Expect.equals(0, result.exitCode);
String version = result.stdout;
- // Check the version of the fletch CLI.
- result = await Process.run('$buildDir/fletch', ['--version']);
+ // Check the version of the dartino CLI.
+ result = await Process.run('$buildDir/dartino', ['--version']);
Expect.equals(0, result.exitCode);
Expect.equals(version, result.stdout);
- // Check the version of the fletch-vm
- result = await Process.run('$buildDir/fletch-vm', ['--version']);
+ // Check the version of the dartino-vm
+ result = await Process.run('$buildDir/dartino-vm', ['--version']);
Expect.equals(0, result.exitCode);
Expect.equals(version, result.stdout);
}
« no previous file with comments | « tests/unsorted/unsorted.status ('k') | third_party/bin/README.md » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698